from open_weather_api.api import Api

class City(Api):
    
    def __init__(self, city = "", config =  None):
        if (city == ""): raise ValueError("Need add City to take weather")
        if (config == None): raise ValueError("Config add")
        self.set_city(city)
        super().__init__(config)

    def set_city(self, city):
        self.__name = f"q={city}"

    def get_city(self):
        return self.__name

    def get_data(self):
        return super().get_data(self.get_city())


from open_weather_api.api import Api
class Coordinates(Api):
    def __init__(self, location='', config=None):
        if (location == '' or location == None): 
            raise ValueError("Need add Coordinates to take weather")
        if (config == None): raise ValueError("Config add")
        self.set_location(location)
        super().__init__(config)

    def set_location(self, location):
        lat_lon = str(location).split(',')
        self.__location = f"lat={lat_lon[0]}&lon={lat_lon[1]}"

    def get_location(self):
        return self.__location

    def get_data(self):
        return super().get_data(self.get_location())


import requests
from open_weather_api.config import Config
from open_weather_api.constants import URL_API

class Api(Config):
    def __init__(self, config):
        print("API")
        print(config)
        print("¡¡API preparada!!")
        super().__init__(config)

    def __get_url(self, find_params):
        """
        Generate URL with all data
        ---------------------------
        Use find params (by city or coordinates)
        Metric o default units system
        Language
        """
        lang = self.get_lang()
        units = self.get_units()
        params = f"{find_params}{lang}{units}"
        type = self.get_type()
        api_key = self.get_api_key()
        # print(f'{URL_API}{type}{params}{api_key}')
        return f'{URL_API}{type}{params}{api_key}'
    
    def get_data(self, find_params):
        """ Create API request URL to take want data"""
        return requests.get(self.__get_url(find_params)).json()
        


URL_API = 'https://api.openweathermap.org/data/2.5/'

# Options to take wetaher
CURRENT = 'weather?'
FORECAST = 'forecast?'

LANGCODES = {
    'af': 'Afrikaans',
    'al': 'Albanian',
    'ar': 'Arabic',
    'az': 'Azerbaijani',
    'bg': 'Bulgarian',
    'ca': 'Catalan',
    'cz': 'Czech',
    'da': 'Danish',
    'de': 'German',
    'el': 'Greek',
    'en': 'English',
    'eu': 'Basque',
    'fa': 'Persian (Farsi)',
    'fi': 'Finnish',
    'fr': 'French',
    'gl': 'Galician',
    'he': 'Hebrew',
    'hi': 'Hindi',
    'hr': 'Croatian',
    'hu': 'Hungarian',
    'id': 'Indonesian',
    'it': 'Italian',
    'ja': 'Japanese',
    'kr': 'Korean',
    'la': 'Latvian',
    'lt': 'Lithuanian',
    'mk': 'Macedonian',
    'no': 'Norwegian',
    'nl': 'Dutch',
    'pl': 'Polish',
    'pt': 'Portuguese',
    'pt_br': 'Português Brasil',
    'ro': 'Romanian',
    'ru': 'Russian',
    'sv': 'Swedish',
    'sk': 'Slovak',
    'sl': 'Slovenian',
    'es': 'Spanish',
    'sr': 'Serbian',
    'th': 'Thai',
    'tr': 'Turkish',
    'uk': 'Ukrainian',
    'vi': 'Vietnamese',
    'zh_cn': 'Chinese Simplified',
    'zhtw':  'Chinese Traditional',
    'zu': 'Zulu'
}



class Config:

    def __init__(self, config):
        print('Iniciando config')
        self.set_api_key(config['key'])
        self.set_units(config['units'])
        self.set_lang(config['lang'])
        self.set_type(config['type'])

    def set_api_key(self, api_key):
        if (api_key == None or api_key == ''):
            raise ValueError('Need add API Key please.')
        self.__api_key = f'&appid={api_key}'

    def get_api_key(self):
        return self.__api_key

    def set_units(self, units):
        self.__units = f'&units=metric' if (units == 'm') else ''

    def get_units(self):
        return self.__units

    def set_lang(self, lang):
        if (lang == '' or lang == None): lang = 'es'
        self.__lang = f'&lang={lang}'

    def get_lang(self):
        return self.__lang

    def set_type(self, type):
        if (type == '' or type == None): 
            raise ValueError("Specify type please. 'current' or 'forecast'")
        self.__type = type

    def get_type(self):
        return self.__type
